@@ -6,8 +6,9 @@ then
   exit 0
 fi
 
+find -name x | xargs rm -f
 cp -r src pymp
-tar -cvf pymp-$1.tar.gz `find pymp -type f | grep -v "~" | grep -v ".pyc"`
+tar -cvf pymp-$1.tar.gz `find pymp -type f | grep -v "~" | grep -v ".pyc" | grep -v .log`
 rm -rf pymp
 
 exit 0
